==> kubernetes-model-apiextensions-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/WebhookConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface WebhookConversionFluent<A extends WebhookConversionFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildClientConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookClientConfig getClientConfig();
  public WebhookClientConfig buildClientConfig();
  public A withClientConfig(WebhookClientConfig clientConfig);
  public Boolean hasClientConfig();
  public WebhookConversionFluent.ClientConfigNested<A> withNewClientConfig();
  public WebhookConversionFluent.ClientConfigNested<A> withNewClientConfigLike(WebhookClientConfig item);
  public WebhookConversionFluent.ClientConfigNested<A> editClientConfig();
  public WebhookConversionFluent.ClientConfigNested<A> editOrNewClientConfig();
  public WebhookConversionFluent.ClientConfigNested<A> editOrNewClientConfigLike(WebhookClientConfig item);
  public A addToConversionReviewVersions(Integer index,String item);
  public A setToConversionReviewVersions(Integer index,String item);
  public A addToConversionReviewVersions(java.lang.String... items);
  public A addAllToConversionReviewVersions(Collection<String> items);
  public A removeFromConversionReviewVersions(java.lang.String... items);
  public A removeAllFromConversionReviewVersions(Collection<String> items);
  public List<String> getConversionReviewVersions();
  public String getConversionReviewVersion(Integer index);
  public String getFirstConversionReviewVersion();
  public String getLastConversionReviewVersion();
  public String getMatchingConversionReviewVersion(Predicate<String> predicate);
  public Boolean hasMatchingConversionReviewVersion(Predicate<String> predicate);
  public A withConversionReviewVersions(List<String> conversionReviewVersions);
  public A withConversionReviewVersions(java.lang.String... conversionReviewVersions);
  public Boolean hasConversionReviewVersions();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ClientConfigNested<N> extends Nested<N>,WebhookClientConfigFluent<WebhookConversionFluent.ClientConfigNested<N>>{
    public N and();
    public N endClientConfig();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/WebhookConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface WebhookConversionFluent<A extends WebhookConversionFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildClientConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookClientConfig getClientConfig();
  public WebhookClientConfig buildClientConfig();
  public A withClientConfig(WebhookClientConfig clientConfig);
  public Boolean hasClientConfig();
  public WebhookConversionFluent.ClientConfigNested<A> withNewClientConfig();
  public WebhookConversionFluent.ClientConfigNested<A> withNewClientConfigLike(WebhookClientConfig item);
  public WebhookConversionFluent.ClientConfigNested<A> editClientConfig();
  public WebhookConversionFluent.ClientConfigNested<A> editOrNewClientConfig();
  public WebhookConversionFluent.ClientConfigNested<A> editOrNewClientConfigLike(WebhookClientConfig item);
  public A addToConversionReviewVersions(int index,String item);
  public A setToConversionReviewVersions(int index,String item);
  public A addToConversionReviewVersions(java.lang.String... items);
  public A addAllToConversionReviewVersions(Collection<String> items);
  public A removeFromConversionReviewVersions(java.lang.String... items);
  public A removeAllFromConversionReviewVersions(Collection<String> items);
  public List<String> getConversionReviewVersions();
  public String getConversionReviewVersion(int index);
  public String getFirstConversionReviewVersion();
  public String getLastConversionReviewVersion();
  public String getMatchingConversionReviewVersion(Predicate<String> predicate);
  public Boolean hasMatchingConversionReviewVersion(Predicate<String> predicate);
  public A withConversionReviewVersions(List<String> conversionReviewVersions);
  public A withConversionReviewVersions(java.lang.String... conversionReviewVersions);
  public Boolean hasConversionReviewVersions();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ClientConfigNested<N> extends Nested<N>,WebhookClientConfigFluent<WebhookConversionFluent.ClientConfigNested<N>>{
    public N and();
    public N endClientConfig();
    
  }
  
}
